#!/bin/zsh
# Copyright 2011 Paul Haensch
# This file is part of Busy
#
# Busy is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Busy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Busy.  If not, see <http://www.gnu.org/licenses/>.

info="$(egrep -o '(^|&)i=[0-9]{10}_[0-9]{3}(&|$)' <<<"${QUERY_STRING}" |tr -d '&i=')"

[ -z "$info" ] && info="$(date +%s)_$(apg -M N -a 1 -n 1 -m 3 -x 3)"
descfile="../Wiki/$info.meta"
commfile="../Wiki/$info.comment.$(date +%s)_$(apg -M N -a 1 -n 1 -m 3 -x 3)"

[ -f "../Wiki/$info.lock" ] && rm "../Wiki/$info.lock"
anchor=$(ls ../Wiki |grep -A2 $info |grep '.meta$' |tail -n1 |cut -d. -f1)

if [ -n "${CONTENT_LENGTH}" -a "${CONTENT_LENGTH}" -gt 0 ]; then
(head -c "${CONTENT_LENGTH}"; echo)|sed 's/&/\n/g' |while read line; do
  if (egrep -xq 'title=.+' <<<"${line}"); then
    title="$(cut -d= -f2- <<<"${line}" |sed 's/+/ /g;s/%/\\x/g')"
    title="$(echo -e "${title}" |sed 's/\t/ /g;s/\r//g;s/\\/\\\\/g' |head -n1)"
  elif (egrep -xq 'desc=.+' <<<"${line}"); then
    description="$(cut -d= -f2- <<<"${line}" |sed 's/+/ /g;s/%/\\x/g')"
    description="$(echo -e "${description}" |sed 's/\r//g;s/\\/\\\\/g')"
  elif (egrep -xq 'comm=.+' <<<"${line}"); then
    comment="$(cut -d= -f2- <<<"${line}" |sed 's/+/ /g;s/%/\\x/g')"
    comment="$(echo -e "${comment}" |sed 's/\r//g;s/\\/\\\\/g')"
  elif (egrep -xq 'cancel=.+' <<<"${line}"); then
    cancel="true"
  fi
done
fi

if [ -z "$cancel" -a -n "$comment" ]; then
  touch "../Wiki/$info"
  echo -e "author=${REMOTE_USER}" > "$commfile"
  echo -e "${comment}" >> "$commfile"
  echo -n "Location: https://${HTTP_HOST}/?p=Wiki&i=$info\n\n"
elif [ -z "$cancel" -a -n "$description" ]; then
  touch "../Wiki/$info"
  echo -e "title=${title}" > "$descfile"
  echo -e "description=${description}" >> "$descfile"
  echo -n "Location: https://${HTTP_HOST}/?p=Wiki#$anchor\n\n"
elif [ -n "$cancel" ]; then
  echo -n "Location: https://${HTTP_HOST}/?p=Wiki#$anchor\n\n"
fi
